@@ -8,22 +8,22 @@ FileHandler::FileHandler(QObject *parent) :
 
 void FileHandler::debugPfo() {
     for (int i=0; i<pfoModel.pfoName.length(); i++) {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << i << "="
                  << pfoModel.pfoName[i].toString() << ":"
                  << pfoModel.pfoDesc[i].toString() << ":"
                  << pfoModel.pfoIsYahoo[i].toBool() ; //<< ":"
-                 //<< pfoModel.pfoNum[i].toInt();
-        #endif
+        //<< pfoModel.pfoNum[i].toInt();
+#endif
     }
 }
 
 // Overloaded function to eliminate appendPfo()
 Q_INVOKABLE int FileHandler::storePfo(QString name, QString desc, bool isYahoo)
 {
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "C_Info: storePfo() " << name << " " << desc << " " << isYahoo;
-    #endif
+#endif
     pfoModel.pfoName.append(name);
     pfoModel.pfoDesc.append(desc);
     pfoModel.pfoIsYahoo.append(isYahoo);
@@ -32,9 +32,9 @@ Q_INVOKABLE int FileHandler::storePfo(QString name, QString desc, bool isYahoo)
 
     if( !f.open( QIODevice::WriteOnly ) )
     {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << "Failed to open for write.";
-        #endif
+#endif
 
         return -1;
     }
@@ -44,9 +44,9 @@ Q_INVOKABLE int FileHandler::storePfo(QString name, QString desc, bool isYahoo)
     if (!pfoModel.pfoName.isEmpty()) {
         for (int i=0; i < pfoModel.pfoName.count(); i++) {
             ts << pfoModel.pfoName[i].toString() << ":" << pfoModel.pfoDesc[i].toString() << ":" << pfoModel.pfoIsYahoo[i].toBool() << endl;
-            #ifdef DBG
+#ifdef DBG
             qDebug() << "C_Info: " << pfoModel.pfoName[i].toString() << ":" << pfoModel.pfoDesc[i].toString() << ":" << pfoModel.pfoIsYahoo[i].toBool();
-            #endif
+#endif
         }
     }
 
@@ -57,17 +57,17 @@ Q_INVOKABLE int FileHandler::storePfo(QString name, QString desc, bool isYahoo)
 
 Q_INVOKABLE int FileHandler::storePfoAll()
 {
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "C_Info: storePfoAll()";
-    #endif
+#endif
 
     QFile f( "/home/user/.stockona/portfolio.cfg" );
 
     if( !f.open( QIODevice::WriteOnly ) )
     {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << "Failed to open for write.";
-        #endif
+#endif
 
         return -1;
     }
@@ -77,9 +77,9 @@ Q_INVOKABLE int FileHandler::storePfoAll()
     if (!pfoModel.pfoName.isEmpty()) {
         for (int i=0; i < pfoModel.pfoName.count(); i++) {
             ts << pfoModel.pfoName[i].toString() << ":" << pfoModel.pfoDesc[i].toString() << ":" << pfoModel.pfoIsYahoo[i].toBool() << endl;
-            #ifdef DBG
+#ifdef DBG
             qDebug() << "C_Info: " << pfoModel.pfoName[i].toString() << ":" << pfoModel.pfoDesc[i].toString() << ":" << pfoModel.pfoIsYahoo[i].toBool();
-            #endif
+#endif
         }
     }
 
@@ -95,9 +95,9 @@ Q_INVOKABLE int FileHandler::loadPfo()
         dir.mkpath("/home/user/.stockona/");
     }
 
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "C_Info: loadPfo --->";
-    #endif
+#endif
 
     QFile f( "/home/user/.stockona/portfolio.cfg" );
 
@@ -107,18 +107,18 @@ Q_INVOKABLE int FileHandler::loadPfo()
 
     if( !f.exists() )
     {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << "C_Info: Local portfolio does not exist.";
-        #endif
+#endif
 
         return -1;
     }
 
     if( !f.open( QIODevice::ReadOnly ) )
     {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << "C_Info: Failed to open for read.";
-        #endif
+#endif
 
         return -1;
     }
@@ -151,9 +151,9 @@ Q_INVOKABLE int FileHandler::loadPfo()
         else {
             // Fix format
             //f.remove();
-            #ifdef DBG
+#ifdef DBG
             qDebug() << "C_Info: Error in loading local portfolio.";
-            #endif
+#endif
 
             return -2;
         }
@@ -171,24 +171,38 @@ Q_INVOKABLE int FileHandler::loadPfo()
 }
 
 Q_INVOKABLE void FileHandler::setPfo(int idx, QString name, QString desc, bool isYahoo) {
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "C_Info: Append: " << name << " " << desc << " " << isYahoo << "to" << idx;
-    #endif
-    pfoModel.pfoName.replace(idx, name);
-    pfoModel.pfoDesc.replace(idx, desc);
-    pfoModel.pfoIsYahoo.replace(idx, isYahoo);
+#endif
+    if (idx>=pfoModel.pfoName.length()) {
+        pfoModel.pfoName.append(name);
+        pfoModel.pfoDesc.append(desc);
+        pfoModel.pfoIsYahoo.append(isYahoo);
+    }
+    else {
+        pfoModel.pfoName.replace(idx, name);
+        pfoModel.pfoDesc.replace(idx, desc);
+        pfoModel.pfoIsYahoo.replace(idx, isYahoo);
+    }
 }
 
 Q_INVOKABLE void FileHandler::removePfo(int idx) {
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "C_Info: Remove portfolio entry " << idx;
-    #endif
+#endif
     pfoModel.pfoName.removeAt(idx);
     pfoModel.pfoDesc.removeAt(idx);
     pfoModel.pfoIsYahoo.removeAt(idx);
     pfoModel.pfoNum.removeAt(idx);
 }
 
+Q_INVOKABLE void FileHandler::removePfoAll() {
+    pfoModel.pfoName.clear();
+    pfoModel.pfoDesc.clear();
+    pfoModel.pfoIsYahoo.clear();
+    pfoModel.pfoNum.clear();
+}
+
 void FileHandler::updatePfoNum(int idx, int num) {
     if (idx < pfoModel.pfoNum.length())
         pfoModel.pfoNum[idx] = num;
@@ -196,23 +210,23 @@ void FileHandler::updatePfoNum(int idx, int num) {
         pfoModel.pfoNum.append(num);
 }
 
-Q_INVOKABLE int FileHandler::deletePfo()
+int FileHandler::deletePfo()
 {
     QFile f( "portfolio.cfg" );
 
     if( !f.exists() )
     {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << "Local portfolio does not exist.";
-        #endif
+#endif
 
         return -1;
     }
 
     f.remove();
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "Delete local portfolio.";
-    #endif
+#endif
 
     f.close();
 
@@ -233,18 +247,18 @@ int FileHandler::loadPosNum(int idx)
 
     if( !f.exists() )
     {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << "C_Info: Position " << filename << " does not exist.";
-        #endif
+#endif
         updatePfoNum(idx, 0);
         return -1;
     }
 
     if( !f.open( QIODevice::ReadOnly ) )
     {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << "C_Info: Failed to open position " << filename << " for read.";
-        #endif
+#endif
         updatePfoNum(idx, 0);
         return -1;
     }
@@ -273,9 +287,9 @@ Q_INVOKABLE int FileHandler::loadPos(int idx)
     filename.append(QString::number(idx));
     filename.append(".pos");
 
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "C_Info: loadPos ---> " << filename;
-    #endif
+#endif
 
     QFile f( filename );
 
@@ -287,9 +301,9 @@ Q_INVOKABLE int FileHandler::loadPos(int idx)
 
     if( !f.exists() )
     {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << "C_Info: Position " << filename << " does not exist.";
-        #endif
+#endif
         // Set pfo's num to 0
         updatePfoNum(idx, 0);
 
@@ -298,9 +312,9 @@ Q_INVOKABLE int FileHandler::loadPos(int idx)
 
     if( !f.open( QIODevice::ReadOnly ) )
     {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << "C_Info: Failed to open position " << filename << " for read.";
-        #endif
+#endif
         // Set pfo's num to 0
         updatePfoNum(idx, 0);
 
@@ -332,9 +346,9 @@ Q_INVOKABLE int FileHandler::loadPos(int idx)
         else {
             // Fix format
             //f.remove();
-            #ifdef DBG
+#ifdef DBG
             qDebug() << "C_Info: Error in loading local position.";
-            #endif
+#endif
 
             return -2;
         }
@@ -352,9 +366,9 @@ Q_INVOKABLE int FileHandler::loadPos(int idx)
 // Overloaded storePos
 Q_INVOKABLE int FileHandler::storePos(int idx, QString symbol, QString exchange, int share, int cost, int stop)
 {
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "C_Info: storePos() " << symbol << " " << exchange << " " << share << " " << cost << " " << stop;
-    #endif
+#endif
 
     posSymbol.append(symbol);
     posExg.append(exchange);
@@ -365,17 +379,17 @@ Q_INVOKABLE int FileHandler::storePos(int idx, QString symbol, QString exchange,
     QString filename = "/home/user/.stockona/";
     filename.append(QString::number(idx));
     filename.append(".pos");
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "C_Info: storePos() into " << filename;
-    #endif
+#endif
 
     QFile f( filename );
 
     if( !f.open( QIODevice::WriteOnly ) )
     {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << "Failed to open " << filename << " for write.";
-        #endif
+#endif
 
         return -1;
     }
@@ -407,17 +421,17 @@ Q_INVOKABLE int FileHandler::storePosAll(int idx)
     QString filename = "/home/user/.stockona/";
     filename.append(QString::number(idx));
     filename.append(".pos");
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "C_Info: storePosAll() into " << filename;
-    #endif
+#endif
 
     QFile f( filename );
 
     if( !f.open( QIODevice::WriteOnly ) )
     {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << "Failed to open " << filename << " for write.";
-        #endif
+#endif
 
         return -1;
     }
@@ -448,21 +462,30 @@ Q_INVOKABLE int FileHandler::storePosAll(int idx)
 
 Q_INVOKABLE void FileHandler::setPos(int idx, QString symbol, QString exchange, int share, int cost, int stop)
 {
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "C_Info: Append: " << symbol << " " << exchange << " " << share << " " << cost << " " << stop;
-    #endif
-    posSymbol.replace(idx, symbol);
-    posExg.replace(idx, exchange);
-    posShare.replace(idx, share);
-    posCost.replace(idx, cost);
-    posStop.replace(idx, stop);
+#endif
+    if (idx>=posSymbol.length()) {
+        posSymbol.append(symbol);
+        posExg.append(exchange);
+        posShare.append(share);
+        posCost.append(cost);
+        posStop.append(stop);
+    }
+    else {
+        posSymbol.replace(idx, symbol);
+        posExg.replace(idx, exchange);
+        posShare.replace(idx, share);
+        posCost.replace(idx, cost);
+        posStop.replace(idx, stop);
+    }
 }
 
 Q_INVOKABLE void FileHandler::removePos(int idx)
 {
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "C_Info: Remove pos entry " << idx;
-    #endif
+#endif
     posSymbol.removeAt(idx);
     posExg.removeAt(idx);
     posShare.removeAt(idx);
@@ -470,7 +493,16 @@ Q_INVOKABLE void FileHandler::removePos(int idx)
     posStop.removeAt(idx);
 }
 
-Q_INVOKABLE void FileHandler::removePosFile(int idx)
+Q_INVOKABLE void FileHandler::removePosAll()
+{
+    posSymbol.clear();
+    posExg.clear();
+    posShare.clear();
+    posCost.clear();
+    posStop.clear();
+}
+
+void FileHandler::removePosFile(int idx)
 {
     QString filename = "/home/user/.stockona/";
     filename.append(QString::number(idx));
@@ -480,20 +512,20 @@ Q_INVOKABLE void FileHandler::removePosFile(int idx)
 
 void FileHandler::debugPos() {
     for (int i=0; i<posSymbol.count(); i++) {
-        #ifdef DBG
+#ifdef DBG
         qDebug() << i << "="
                  << posSymbol[i].toString() << ":"
                  << posExg[i].toString() << ":"
                  << posShare[i].toInt() << ":"
                  << posCost[i].toInt() << ":"
                  << posStop[i].toInt();
-        #endif
+#endif
     }
 }
 
 
 // Utility function
-QVariantList FileHandler::calcPerformance (int i, int price) {
+Q_INVOKABLE QVariantList FileHandler::calcPerformance (int i, int price) {
     QVariantList perfData;
 
     int cost = posCost[i].toInt() * posShare[i].toInt();
@@ -512,9 +544,60 @@ QVariantList FileHandler::calcPerformance (int i, int price) {
     }
 
 
-    #ifdef DBG
+#ifdef DBG
     qDebug() << "(cost, value, gainPtg)=" << cost << " " << value;
-    #endif
+#endif
 
     return perfData;
 }
+
+Q_INVOKABLE QVariantList FileHandler::parseCSV (const QString data) {
+//    std::vector<std::string> tokenize(const std::string& str,char delimiter) {
+
+        QVariantList tokens;
+        std::string str = data.toStdString();
+
+//        QString debug("13,14\n");
+//        str = debug.toStdString();
+
+        char delimiter;
+        strcpy(&delimiter, ",");
+
+        unsigned int pos = 0;
+        bool quotes = false;
+        std::string field = "";
+
+        while(str[pos] != 0x00 && pos < str.length()){
+            char c = str[pos];
+            // Start of quote
+            if ( !quotes && c == '"' ){
+                quotes = true;
+            // End of quote
+            } else if ( quotes && c== '"' ){
+//                if (pos + 1 <str.length() && str[pos+1]== '"' ){
+//                    field.push_back(c);
+//                    pos++;
+//                } else {
+                    quotes = false;
+//                }
+            } else if ( !quotes && c == delimiter) {
+                tokens.push_back(field.c_str());
+                field.clear();
+            // new line or CR
+            } else if ( !quotes && c == 0x0A ){
+                tokens.push_back(field.c_str());
+                field.clear();
+            } else if ( c!= 0x0D ){
+                field.push_back(c);
+            }
+//#ifdef DBG
+//            qDebug() << "pos=" << pos << "field=" << field.c_str() << "c=" << c;
+//#endif
+            pos++;
+        }
+//#ifdef DBG
+//        //qDebug()<<data;
+//        qDebug()<<tokens;
+//#endif
+        return tokens;
+}
