@@ -1,6 +1,7 @@
 #ifndef FILEHANDLER_H
 #define FILEHANDLER_H
 
+#include <string>
 #include <QIODevice>
 #include <QFile>
 #include <QTextStream>
@@ -51,7 +52,8 @@ public:
     Q_INVOKABLE int loadPfo();
     Q_INVOKABLE void setPfo(int, QString , QString , bool);
     Q_INVOKABLE void removePfo(int);
-    Q_INVOKABLE int deletePfo();
+    Q_INVOKABLE void removePfoAll();
+    int deletePfo();
     void debugPfo();
     void updatePfoNum(int, int);
 
@@ -61,11 +63,12 @@ public:
     Q_INVOKABLE int loadPos(int);
     Q_INVOKABLE void setPos(int, QString, QString, int , int, int);
     Q_INVOKABLE void removePos(int);
-    Q_INVOKABLE void removePosFile(int);
+    Q_INVOKABLE void removePosAll();
+    void removePosFile(int);
 
     // Utility function
     Q_INVOKABLE QVariantList calcPerformance(int, int);
-
+    Q_INVOKABLE QVariantList parseCSV(const QString);
 
     void debugPos();
     int loadPosNum(int);
