@@ -7,7 +7,6 @@
 
 #ifndef LISTMODEL_H
 #define LISTMODEL_H
-
 #include <QAbstractListModel>
 #include <QList>
 #include <QVariant>
@@ -18,7 +17,7 @@ class ListItem: public QObject {
 public:
   ListItem(QObject* parent = 0) : QObject(parent) {}
   virtual ~ListItem() {}
-  virtual QString id() const = 0;
+  //virtual QString id() const = 0;
   virtual QVariant data(int role) const = 0;
   virtual QHash<int, QByteArray> roleNames() const = 0;
 
@@ -35,13 +34,15 @@ public:
   ~ListModel();
   int rowCount(const QModelIndex &parent = QModelIndex()) const;
   QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
-  void appendRow(ListItem* item);
+  void append(ListItem* item);
   void appendRows(const QList<ListItem*> &items);
-  void insertRow(int row, ListItem* item);
-  bool removeRow(int row, const QModelIndex &parent = QModelIndex());
+  void insert(int row, ListItem* item);
+  bool remove(int row, const QModelIndex &parent = QModelIndex());
   bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex());
+  //bool get(int row, const QModelIndex &parent = QModelIndex());
+  //bool set(int row, const QModelIndex &parent = QModelIndex());
   ListItem* takeRow(int row);
-  ListItem* find(const QString &id) const;
+  //ListItem* find(const QString &id) const;
   QModelIndex indexFromItem( const ListItem* item) const;
   void clear();
 
