@@ -4,7 +4,7 @@
 #include "qmlapplicationviewer.h"
 #include "windowhelper.h"
 #include "filehandler.h"
-#include "networkhelper.h"
+//#include "networkhelper.h"
 //#include "pfomodel.h"
 //#include "QString"
 
@@ -35,9 +35,9 @@ int main(int argc, char *argv[])
     viewer.rootContext()->setContextProperty("fileHandler", fileHandler);
 
     // Share QML NetworkAccessManger for QT C++ network operations
-    NetworkHelper *nwHelper = new NetworkHelper();
-    QNetworkAccessManager * manager = viewer.rootContext()->engine()->networkAccessManager();
-    nwHelper->setNetworkAccessManager(manager);
+    //NetworkHelper *nwHelper = new NetworkHelper();
+    //QNetworkAccessManager * manager = viewer.rootContext()->engine()->networkAccessManager();
+    //nwHelper->setNetworkAccessManager(manager);
     //nwHelper->doWebRequest("POST", "https://www.google.com/accounts/ClientLogin?Email=&Passwd=", 0);
 
     // C++ ListModel
